@@ -1,34 +1,55 @@
+# -*- coding: utf-8 -*-
+
+"""
+hooks to AA
+"""
+
 from django.utils.translation import ugettext_lazy as _
 
-from allianceauth.services.hooks import MenuItemHook, UrlHook
 from allianceauth import hooks
+from allianceauth.services.hooks import MenuItemHook, UrlHook
 
 from . import urls, __title__
 
 
 class AaTimezonesMenuItem(MenuItemHook):
     """ This class ensures only authorized users will see the menu entry """
+
     def __init__(self):
         # setup menu entry for sidebar
         MenuItemHook.__init__(
             self,
             _(__title__),
-            'far fa-clock fa-fw',
-            'timezones:index',
-            navactive=['timezones:index']
+            "far fa-clock fa-fw",
+            "timezones:index",
+            navactive=["timezones:index"],
         )
 
     def render(self, request):
-        if request.user.has_perm('timezones.basic_access'):
+        """
+        only if the user has access to this app
+        :param request:
+        :return:
+        """
+        if request.user.has_perm("timezones.basic_access"):
             return MenuItemHook.render(self, request)
-        return ''
+
+        return ""
 
 
-@hooks.register('menu_item_hook')
+@hooks.register("menu_item_hook")
 def register_menu():
+    """
+    register our menu item
+    :return:
+    """
     return AaTimezonesMenuItem()
 
 
-@hooks.register('url_hook')
+@hooks.register("url_hook")
 def register_urls():
-    return UrlHook(urls, 'timezones', r'^timezones/')
+    """
+    register our base url
+    :return:
+    """
+    return UrlHook(urls, "timezones", r"^timezones/")
